﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using System;

namespace WSUniversalLib.UnitTest
{
    [TestClass]
    public class UnitTest
    {

        /// <summary>
        /// Метод возвращает требуемый результат при всех правильных данных.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_CorrectInput()
        {
            Assert.AreEqual(114147, Calculation.GetQuantityForProduct(3, 1, 15, 20, 45));
        }

        /// <summary>
        /// Метод возвращает требуемый результат при неправильном типе продукции.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_IncorrectInputProduct()
        {
            Assert.AreEqual(-1, Calculation.GetQuantityForProduct(0, 1, 15, 20, 45));
        }
        /// <summary>
        /// Метод возвращает требуемый результат при неправильном типе продукции.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_IncorrectInputMaterial()
        {
            Assert.AreEqual(-1, Calculation.GetQuantityForProduct(3, 0, 15, 20, 45));
        }

        /// <summary>
        /// Проверка, что метод возвращает целочисленное значение.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_IsInt()
        {
            Assert.IsInstanceOfType(Calculation.GetQuantityForProduct(3, 1, 15, 20, 45), typeof(int));
        }
        
        /// <summary>
        /// Проверка, что метод округляет в большую сторону.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_Round()
        {
            Assert.IsTrue(Calculation.GetQuantityForProduct(3, 1, 15, 20, 45) > 114146.4);
        }

        /// <summary>
        /// Проверка, что вознкиает исключение, если ввести число продукции <= 0 при правильных типах.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_ExceptionInvalidCount()
        {
            Assert.ThrowsException<System.ArgumentException>(()=> Calculation.GetQuantityForProduct(3, 1, 0, 20, 45));
        }
        /// <summary>
        /// Проверка, что вознкиает исключение, если ввести ширину <= 0 при правильных типах.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_ExceptionInvalidWidth()
        {
            Assert.ThrowsException<System.ArgumentException>(()=> Calculation.GetQuantityForProduct(3, 1, 15, -20, 45));
        }
        /// <summary>
        /// Проверка, что вознкиает исключение, если ввестидлину <= 0 при правильных типах.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_ExceptionInvalidLength()
        {
            Assert.ThrowsException<System.ArgumentException>(()=> Calculation.GetQuantityForProduct(3, 1, 15, 20, -45));
        }
        /// <summary>
        /// Проверка, что вознкиает исключение, если ввести все параметры <= 0 при правильных типах.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_ExceptionInvalidParametrWithoutType()
        {
            Assert.ThrowsException<System.ArgumentException>(()=> Calculation.GetQuantityForProduct(3, 1, 0, -20, -45));
        }
        /// <summary>
        /// Проверка, что вознкиает исключение, если ввести все параметры <= 0 при неправильных типах.
        /// </summary>
        [TestMethod]
        public void GetQuantityForProduct_ExceptionWithAllInvalidParametr()
        {
            Assert.ThrowsException<System.ArgumentException>(()=> Calculation.GetQuantityForProduct(5, 6, 0, -20, -45));
        }


    }
}
