﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WSUniversalLib
{
    public static class Calculation
    {
        /// <summary>
        /// Список типов продуктов.
        /// </summary>
        static List<int> listIdProductType = new List<int>() { 1, 2, 3 };
        /// <summary>
        /// Список коэфициентов, соответсвующих продуктам.
        /// </summary>
        static List<float> listCoefProductType = new List<float>() { (float)1.1, (float)2.5, (float)8.43 };
        /// <summary>
        /// Список типов материалов.
        /// </summary>
        static List<int> listIdMaterialType = new List<int>() { 1, 2 };
        /// <summary>
        /// Список процентов брака, соответсвующих материалам.
        /// </summary>
        static List<float> listCoefMaterialType = new List<float>() { (float)0.003, (float)0.0012 };

        /// <summary>
        ///  Расчет целого количество сырья, необходимого для производства определенного 
        ///  количества продукции, учитывая возможный брак материалов.
        /// </summary>
        /// <param name="productType">Номер типа продукции.</param>
        /// <param name="materialType">Номер типа материала.</param>
        /// <param name="count">Количество продукции.</param>
        /// <param name="width">Ширина продукции.</param>
        /// <param name="length">Высота продукции.</param>
        /// <returns></returns>
        public static int GetQuantityForProduct(int productType, int materialType, int count, float width, float length)
        {
            int result = 0;
            if (count <= 0 || width <= 0 || length <= 0)
            {
                throw new ArgumentException();
            }
            if (!listIdProductType.Contains(productType) || !listIdMaterialType.Contains(materialType))
                return -1;
            float squard = width * length;
            var quantity = (squard * listCoefProductType[listIdProductType.IndexOf(productType)]) * count;
            var quantityWithTrash = quantity + quantity * listCoefMaterialType[listIdMaterialType.IndexOf(materialType)];
            result = Convert.ToInt32(Math.Ceiling(quantityWithTrash));
            return result; ;
        }
    }
}
